OC.L10N.register(
    "comments",
    {
    "Comments" : "评论",
    "You commented" : "您的评论",
    "%1$s commented" : "%1$s 已评论",
    "{author} commented" : "{author} 评论了",
    "You commented on %1$s" : "您在 %1$s 的评论",
    "You commented on {file}" : "您对 {file} 的评论",
    "%1$s commented on %2$s" : "%1$s 评论了 %2$s",
    "{author} commented on {file}" : "{author} 对 {file} 的评论",
    "<strong>Comments</strong> for files" : "文件的<strong>评论</strong>",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "用户在“ {file}”中的评论中提到了您，此评论已被删除",
    "{user} mentioned you in a comment on “{file}”" : "{user} 在 “{file}” 的评论中提到了您",
    "Files app plugin to add comments to files" : "文件 应用插件可向文件添加注释",
    "Edit comment" : "编辑评论",
    "Delete comment" : "删除评论",
    "New comment …" : "新评论 ...",
    "Post" : "发布",
    "Cancel" : "取消",
    "[Deleted user]" : "[已删除的用户]",
    "No comments yet, start the conversation!" : "还没有评论，开始对话吧！",
    "More comments …" : "更多评论 ...",
    "Save" : "保存",
    "Allowed characters {count} of {max}" : "当前字数： {count}，最多允许：{max}",
    "Error occurred while retrieving comment with ID {id}" : "取回 ID {id} 的评论时发生错误",
    "Error occurred while updating comment with id {id}" : "更新 id 为 {id} 的评论出错",
    "Error occurred while posting comment" : "发表评论时发生错误",
    "_%n unread comment_::_%n unread comments_" : ["%n 条未读评论"],
    "_1 new comment_::_{unread} new comments_" : ["{unread} 条新评论"],
    "Comment" : "评论"
},
"nplurals=1; plural=0;");
